The Immigration Services Tribunal was established under the Immigration and Asylum Act 1999 to hear appeals from decisions of the Immigration Services Commissioner and disciplinary charges laid by the Immigration Services Commissioner against qualified persons. In 2009/10 its functions were transferred to the General Regulatory Chamber of the First-tier Tribunal, which hears appeals against decisions made by government regulatory bodies.
